@@ -1,7 +1,6 @@
 """The pysqueezebox.Player() class."""
 import asyncio
 import logging
-
 import async_timeout
 
 from .const import REPEAT_MODE, SHUFFLE_MODE
@@ -330,7 +329,7 @@ class Player:
         if timeout == 0:
             return True
         try:
-            with async_timeout.timeout(timeout):
+            async with async_timeout.timeout(timeout):
                 return await self.create_property_future(prop, lambda x: value == x)
         except asyncio.TimeoutError:
             _LOGGER.error("Timed out waiting for %s to have value %s", prop, value)
@@ -346,7 +345,6 @@ class Player:
 
         Return True if successful, False if update fails.
         """
-
         # cancel pending poll if we were called manually
         if self._poll and not self._poll.done():
             self._poll.cancel()
@@ -493,9 +491,7 @@ class Player:
         return await self._wait_for_property("current_index", target_index, timeout)
 
     async def async_time(self, position, timeout=TIMEOUT):
-        """
-        Seek to a particular time in track.
-        """
+        """Seek to a particular time in track."""
         if not position:
             return False
 
@@ -507,7 +503,7 @@ class Player:
             return False
 
         try:
-            with async_timeout.timeout(timeout):
+            async with async_timeout.timeout(timeout):
                 # We have to use a fuzzy match to see if the player got the command.
                 await self.create_property_future(
                     "time", lambda time: time and position <= time <= position + timeout
@@ -528,21 +524,30 @@ class Player:
         Play a specific track by url.
 
         cmd: "play" or "load" - replace current playlist (default)
+        cmd: "play_now" - adds to current spot in playlist
         cmd: "insert" - adds next in playlist
         cmd: "add" - adds to end of playlist
         """
-        if cmd in ["insert", "add"] and self.playlist:
+        index = self.current_index or 0
+
+        if cmd in ["play_now", "insert", "add"] and self.playlist:
             await self.async_update()
             target_playlist = self.playlist_urls
             if cmd == "add":
                 target_playlist.append({"url": url})
             else:
-                target_playlist.insert(self.current_index + 1, {"url": url})
+                if cmd == "insert":
+                    index += 1
+                target_playlist.insert(index, {"url": url})
         else:
             target_playlist = [{"url": url}]
 
-        if not await self.async_query("playlist", cmd, url):
-            return False
+        if cmd == "play_now":
+            await self.async_load_playlist(target_playlist)
+            await self.async_index(index)
+        else:
+            if not await self.async_query("playlist", cmd, url):
+                return False
         return await self._wait_for_property("playlist_urls", target_playlist, timeout)
 
     async def async_load_playlist(self, playlist_ref, cmd="load"):
@@ -622,7 +627,7 @@ class Player:
 
         await self.async_update()
         try:
-            with async_timeout.timeout(timeout):
+            async with async_timeout.timeout(timeout):
                 await self.create_property_future(
                     "sync_group", lambda sync_group: other_player_id in sync_group
                 )
